/*
 * libexplain - Explain errno values returned by libc functions
 * Copyright (C) 2009 Peter Miller
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#include <libexplain/ac/linux/if_frad.h>

#include <libexplain/buffer/dlci_add.h>
#include <libexplain/buffer/pointer.h>
#include <libexplain/path_is_efault.h>


#ifdef HAVE_LINUX_IF_FRAD_H

void
explain_buffer_dlci_add(explain_string_buffer_t *sb,
    const struct dlci_add *data)
{
    if (explain_pointer_is_efault(data, sizeof(*data)))
        explain_buffer_pointer(sb, data);
    else
    {
        explain_string_buffer_puts(sb, "{ devname = ");
        explain_string_buffer_puts_quoted_n
        (
            sb,
            data->devname,
            sizeof(data->devname)
        );
        explain_string_buffer_printf(sb, ", dlci %d }", data->dlci);
    }
}

#else

void
explain_buffer_dlci_add(explain_string_buffer_t *sb,
    const struct dlci_add *data)
{
    explain_buffer_pointer(sb, data);
}

#endif
